package banco.fachada;

import banco.conta.*;
import banco.cliente.*;

public class Fachada {

  private static Fachada instancia;
  private CadastroContas contas;
  private CadastroClientes clientes;

  protected Fachada() {
	  initCadastros();
  }

  private void initCadastros() {
	IRepositorioContas rep = new ArrayContas();
	contas = new CadastroContas(rep);
	IRepositorioClientes repClientes = new ListaClientes();
	clientes = new CadastroClientes(repClientes);
  }
  public static Fachada obterInstancia() {
	 if (instancia == null) {
	   instancia = new Fachada();
	 }
	 return instancia;
  }

  //metodos par amanipular clientes
  public void atualizar(Cliente c) throws ClienteInexistenteException{
	  clientes.atualizar(c);
  }
  public Cliente procurarCliente(String cpf) throws ClienteInexistenteException{
	return clientes.procurar(cpf);
  }
  public void inserir(Cliente c) throws ClienteExistenteException{
	clientes.inserir(c);
  }
  public void removerCliente(String cpf) throws ClienteInexistenteException{
	  clientes.remover(cpf);
  }

  //metodos para manipular contas
  public void atualizar(ContaAbstrata c) throws ContaInexistenteException{
	contas.atualizar(c);
  }
  public ContaAbstrata procurarConta(String n) throws ContaInexistenteException{
	  return contas.procurar(n);
  }
  public void inserir(ContaAbstrata c)
    throws ContaExistenteException, ClienteInexistenteException{

    Cliente cli = c.getCliente();
    if(cli != null){
      cli = clientes.procurar(cli.getCpf());
      c.setCliente(cli);
      contas.inserir(c);
    }else {
      throw new ClienteInexistenteException("Cliente nao cadastrado");
    }
  }
  public void removerConta(String n) throws ContaInexistenteException{
	  contas.remover(n);
  }
  public void creditar(String n, double v) throws ContaInexistenteException{
    contas.creditar(n, v);
  }
  public void debitar(String n, double v)
    throws ContaInexistenteException, SaldoInsuficienteException{

    contas.debitar(n, v);
  }
  public void transferir(String origem, String destino, double val)
    throws ContaInexistenteException, SaldoInsuficienteException{

      contas.transferir(origem, destino, val);
  }
  public ColecaoContasIteravel procurarContas(String cpfCliente){
    return contas.procurarContas(cpfCliente);
  }
}
